﻿<#########################################################################################################
 # File: Uninstall-WindowsAdminCenterHA.ps1
 #
 # .DESCRIPTION
 #
 #  Uninstall Windows Admin Center Ha service.
 #
 #  Copyright (c) Microsoft Corp 2017.
 #
 #########################################################################################################>

#Requires -RunAsAdministrator

$ErrorActionPreference = "Stop"

$resource = Get-ClusterResource | where {$_.Name -like '*Windows Admin Center*'}
if(-Not $resource)
{
    write-error 'Windows Admin Center is not installed.'
}

$ownerGroup = $resource.OwnerGroup
Remove-ClusterGroup $ownerGroup.Name -RemoveResources -Force

$nodes = Get-ClusterNode

foreach($node in $nodes)
{
    Write-Output "uninstalling Windows Admin Center on node: $node" 

    $command = {
		$queryResult = gwmi -Query "SELECT ProductCode FROM Win32_Property WHERE Property='UpgradeCode' AND Value='{af3e4932-2d63-46f8-a37f-b6acfd5378cd}'"
		if($queryResult)
		{
			$productCode = $queryResult.ProductCode
			$app = Get-WmiObject Win32_Product -filter "IdentifyingNumber='$productCode'"
			if($app)
			{
				$app.UnInstall() | Out-Null
				$registryPath = "HKLM:\Software\Microsoft\ServerManagementGateway"
				if(Test-Path $registryPath)
				{
					Remove-Item $registryPath -Recurse
				}
			}
		}
    }

    Invoke-Command -ComputerName $node.Name -ScriptBlock $command
}

Write-Output "Uninstallation is completed."

